@@ -702,22 +702,119 @@ def test_parameter_line_without_colon_keyword_only(parse_google):
     assert "Empty" in warnings[1]
 
 
-# TODO: possible feature
-# def test_extra_parameter(parse_google):
-#     """Warn on extra parameter in docstring.
-#
-#     Parameters:
-#         parse_google: Fixture parser.
-#     """
-#     docstring = """
-#         Parameters:
-#             x: Integer.
-#             y: Integer.
-#     """
+def test_warn_about_unknown_parameters(parse_google):
+    """Warn about unknown parameters in "Parameters" sections.
 
-#     sections, warnings = parse_google(docstring)
-#     assert len(sections) == 1
-#     assert len(warnings) == 2
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Parameters:
+            x (int): Integer.
+            y (int): Integer.
+    """
+
+    _, warnings = parse_google(
+        docstring,
+        parent=Function(
+            "func",
+            parameters=Parameters(
+                Parameter("a"),
+                Parameter("y"),
+            ),
+        ),
+    )
+    assert len(warnings) == 1
+    assert "'x' does not appear in the function signature" in warnings[0]
+
+
+def test_never_warn_about_unknown_other_parameters(parse_google):
+    """Never warn about unknown parameters in "Other parameters" sections.
+
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Other Parameters:
+            x (int): Integer.
+            z (int): Integer.
+    """
+
+    _, warnings = parse_google(
+        docstring,
+        parent=Function(
+            "func",
+            parameters=Parameters(
+                Parameter("a"),
+                Parameter("y"),
+            ),
+        ),
+    )
+    assert not warnings
+
+
+def test_unknown_params_scan_doesnt_crash_without_parameters(parse_google):
+    """Assert we don't crash when parsing parameters sections and parent object does not have parameters.
+
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Parameters:
+            this (str): This.
+            that (str): That.
+    """
+
+    _, warnings = parse_google(docstring, parent=Module("mod"))
+    assert not warnings
+
+
+def test_class_uses_init_parameters(parse_google):
+    """Assert we use the `__init__` parameters when parsing classes' parameters sections.
+
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Parameters:
+            x: X value.
+    """
+    parent = Class("c")
+    parent["__init__"] = Function("__init__", parameters=Parameters(Parameter("x", annotation="int")))
+    sections, warnings = parse_google(docstring, parent=parent)
+    assert not warnings
+    argx = sections[0].value[0]
+    assert argx.name == "x"
+    assert argx.annotation == "int"
+    assert argx.description == "X value."
+
+
+def test_dataclass_uses_attributes(parse_google):
+    """Assert we use the class' attributes as parameters when parsing dataclasses' parameters sections.
+
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Parameters:
+            auth: Auth method.
+            base_url: Base URL.
+    """
+    parent = Class("c")
+    parent.labels.add("dataclass")
+    parent["auth"] = Attribute("auth", annotation="Optional[str]", value="None")
+    parent["base_url"] = Attribute("base_url", annotation="str", value="'https://api.example.com'")
+    sections, warnings = parse_google(docstring, parent=parent)
+    assert not warnings
+    auth, base_url = sections[0].value
+    assert auth.name == "auth"
+    assert auth.annotation == "Optional[str]"
+    assert auth.description == "Auth method."
+    assert auth.default == "None"
+    assert base_url.name == "base_url"
+    assert base_url.annotation == "str"
+    assert base_url.description == "Base URL."
+    assert base_url.default == "'https://api.example.com'"
 
 
 # TODO: possible feature
